@@ -9,24 +9,26 @@ open_url = "https://open.gauth.co.kr/user"
 def code_issuance(email: str, password:str) -> str :
     URL = server_url + "/oauth/code"
     response = requests.post(URL, json={"email":email, "password" : password})
-    print("성공적으로 코드를 보냈습니다.")
-    return response.content
+    response_json = response.content.decode("utf-8")
+    return response_json
 
 def token_issuance(code : str, clientId: str, clientSecret: str, redirectUri: str) -> str :
     URL = server_url + "/oauth/token"
     response = requests.post(URL, json={"code" : code,
-                                    "clientId": clientId,
+                                        "clientId": clientId,
                                         "clientSecret": clientSecret,
                                         "redirectUri" : redirectUri})
-    return response.content
+    response_json = response.content.decode("utf-8")
+    return response_json
 
 def token_reissuance(refreshToken : str) -> str:
     URL = server_url + "/oauth/token"
     response = requests.patch(URL, headers={"refreshToken" : "Bearer " + refreshToken})
-    return response.content
+    response_json = response.content.decode("utf-8")
+    return response_json
 
-def user_info(refreshToken : str) -> str:
+def user_info(accessToken : str) -> str:
     URL = open_url + "/user"
-    response = requests.get(URL, headers={"Authorization": "Bearer " + refreshToken})
-
-    return response.content
\ No newline at end of file
+    response = requests.get(URL, headers={"Authorization": "Bearer " + accessToken})
+    response_json = response.content.decode("utf-8")
+    return response_json
\ No newline at end of file
